import { AxiosResponse } from 'axios';
/**
 * Log levels to indicate importance of the logged message.
 * Every level corresponds to a certain color.
 *
 * - INFO: no color
 * - WARN: yellow
 * - ERROR: red
 * - DEBUG: gray
 *
 * Messages with DEBUG level are only displayed if explicitly enabled.
 */
export declare const enum LoggerLevel {
    INFO = "info",
    WARN = "warn",
    ERROR = "error",
    DEBUG = "debug"
}
export declare type LogMessage = (level: LoggerLevel, message: string, ...parameters: any[]) => void;
export declare class DaikinApi {
    private readonly user;
    private readonly password;
    private readonly refreshInterval;
    private readonly log;
    private _token;
    private _locations;
    private _tokenExpiration;
    private _devices;
    constructor(user: string, password: string, refreshInterval: number, log: LogMessage);
    Initialize(): Promise<void>;
    getData(): Promise<void>;
    getToken(): Promise<void>;
    setToken(response: AxiosResponse<any>): Promise<void>;
    getLocation(): Promise<any>;
    getDevices(): Promise<any>;
    getDeviceData(device: any): Promise<any>;
    refreshToken(): Promise<void> | undefined;
    getRequest(uri: string): Promise<any>;
    getDeviceList(): any;
    getDeviceName(deviceName: number, deviceNameCustom: string): string;
    deviceHasData(deviceId: string): boolean;
    getCurrentStatus(deviceId: string): number;
    getCurrentTemp(deviceId: string): number;
    getTargetState(deviceId: string): number;
    getTargetTemp(deviceId: string): number;
    getCurrentHumidity(deviceId: string): number;
    getOutdoorHumidity(deviceId: string): number;
    getTargetHumidity(deviceId: string): number;
    getAirQualityLevel(deviceId: string, forIndoor: boolean): number;
    getOzone(deviceId: string, forIndoor: boolean): number;
    getAirQualityValue(deviceId: string, forIndoor: boolean): number;
    getPM2_5Density(deviceId: string, forIndoor: boolean): number;
    getVocDensity(deviceId: string, forIndoor: boolean): number;
    getDisplayUnits(deviceId: string): number;
    setTargetTemp(deviceId: string, requestedTemp: number): Promise<boolean>;
    setTargetState(deviceId: string, requestedState: number): Promise<boolean>;
    setDisplayUnits(deviceId: string, requestedUnits: number): Promise<boolean>;
    setTargetHumidity(deviceId: string, requestedHumidity: number): Promise<boolean>;
    logError(message: string, error: any): boolean;
}
//# sourceMappingURL=daikinapi.d.ts.map